@@ -15,7 +15,10 @@ let kind_to_stack
 ;;
 
 let make (type stack state parsed_value) kind mode make_value
-  : (module S with type parsed_value = parsed_value)
+  : (module S
+       with type parsed_value = parsed_value
+        and type State.t = (state, stack) Automaton_state.t
+        and type Stack.t = stack)
   =
   (module struct
     type nonrec parsed_value = parsed_value
@@ -59,7 +62,10 @@ let make (type stack state parsed_value) kind mode make_value
 ;;
 
 let make_eager (type stack state parsed_value) kind make_value
-  : (module S_eager with type parsed_value = parsed_value)
+  : (module S_eager
+       with type parsed_value = parsed_value
+        and type State.t = (state, stack) Automaton_state.t
+        and type Stack.t = stack)
   =
   (module struct
     type nonrec parsed_value = parsed_value
@@ -81,13 +87,16 @@ let make_eager (type stack state parsed_value) kind make_value
 
       include Read_only
 
-      let create ?pos ?(no_sexp_is_error = false) f =
+      let create ?pos ?(reraise_notrace = false) ?(no_sexp_is_error = false) f =
         let got_sexp state stack =
           let parsed_value = make_value state stack in
           f state parsed_value;
           Stack.empty
         in
-        A.create ?initial_pos:pos (Eager { got_sexp; no_sexp_is_error }) kind
+        A.create
+          ?initial_pos:pos
+          (Eager { got_sexp; reraise_notrace; no_sexp_is_error })
+          kind
       ;;
 
       let reset = A.reset
@@ -123,11 +132,11 @@ let make_eager (type stack state parsed_value) kind make_value
         lexbuf.lex_curr_pos <- p;
         lexbuf.lex_start_pos <- p;
         lexbuf.lex_curr_p
-        <- { lexbuf.lex_curr_p with
-             pos_lnum = pos.line
-           ; pos_cnum = pos.offset
-           ; pos_bol = pos.offset - pos.col
-           }
+          <- { lexbuf.lex_curr_p with
+               pos_lnum = pos.line
+             ; pos_cnum = pos.offset
+             ; pos_bol = pos.offset - pos.col
+             }
       ;;
 
       let rec feed_lexbuf t (lexbuf : Lexing.lexbuf) stack =
