@@ -77,20 +77,20 @@ let sexp_of_pos =
      let bnds__001_ =
        let arg__007_ = sexp_of_int offset__006_ in
        (Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "offset"; arg__007_ ] :: bnds__001_
-        : _ Stdlib.List.t)
+         : _ Stdlib.List.t)
      in
      let bnds__001_ =
        let arg__005_ = sexp_of_int col__004_ in
        (Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "col"; arg__005_ ] :: bnds__001_
-        : _ Stdlib.List.t)
+         : _ Stdlib.List.t)
      in
      let bnds__001_ =
        let arg__003_ = sexp_of_int line__002_ in
        (Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "line"; arg__003_ ] :: bnds__001_
-        : _ Stdlib.List.t)
+         : _ Stdlib.List.t)
      in
      Sexplib0.Sexp.List bnds__001_
-     : pos -> Sexplib0.Sexp.t)
+    : pos -> Sexplib0.Sexp.t)
 ;;
 
 [@@@end]
@@ -111,15 +111,15 @@ let sexp_of_range =
      let bnds__008_ =
        let arg__012_ = sexp_of_pos end_pos__011_ in
        (Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "end_pos"; arg__012_ ] :: bnds__008_
-        : _ Stdlib.List.t)
+         : _ Stdlib.List.t)
      in
      let bnds__008_ =
        let arg__010_ = sexp_of_pos start_pos__009_ in
        (Sexplib0.Sexp.List [ Sexplib0.Sexp.Atom "start_pos"; arg__010_ ] :: bnds__008_
-        : _ Stdlib.List.t)
+         : _ Stdlib.List.t)
      in
      Sexplib0.Sexp.List bnds__008_
-     : range -> Sexplib0.Sexp.t)
+    : range -> Sexplib0.Sexp.t)
 ;;
 
 [@@@end]
@@ -173,7 +173,6 @@ end = struct
          else
            set16
      ]}
-
   *)
 end
 
@@ -225,10 +224,10 @@ module Builder = struct
     ; mutable chunk_pos : int
     ; mutable filled_chunks : Chunk.t list (* Filled chunks in reverse order *)
     ; mutable offset : int
-    (* Offset of the last saved position or newline plus
+        (* Offset of the last saved position or newline plus
        one, or [initial_pos] *)
     ; mutable int_buf : int
-    (* the [num_bits] least significant bits of [int_buf]
+        (* the [num_bits] least significant bits of [int_buf]
        are the bits not yet pushed to [chunk]. *)
     ; mutable num_bits : int (* number of bits stored in [int_buf] *)
     ; mutable initial_pos : pos
@@ -379,6 +378,14 @@ end
 
 type positions = t
 
+let rec sub_sexp_count (sexp : Sexp.t) =
+  match sexp with
+  | Atom _ -> 1
+  | List l -> List.fold_left l ~init:1 ~f:(fun acc x -> acc + sub_sexp_count x)
+;;
+
+let sexp_positions_count sexp = sub_sexp_count sexp * 2
+
 module Iterator : sig
   type t
 
@@ -389,6 +396,7 @@ module Iterator : sig
   (* [advance t ~skip] ignores [skip] saved positions and returns the next saved position.
      Raises [No_more] when reaching the end of the position set. *)
   val advance_exn : t -> skip:int -> pos
+  val advance_sexp_exn : t -> Sexp.t -> range
 end = struct
   type t =
     { mutable chunk : Chunk.t
@@ -515,6 +523,13 @@ end = struct
       else advance t ~skip:(skip - 1) ~offset_shift:0 ~offset_shift_num_bits:0
     | None -> advance t ~skip ~offset_shift:0 ~offset_shift_num_bits:0
   ;;
+
+  let advance_sexp_exn t sexp =
+    let positions_count = sexp_positions_count sexp in
+    let start_pos = advance_exn t ~skip:0 in
+    let last_pos = advance_exn t ~skip:(positions_count - 2) in
+    make_range_incl ~start_pos ~last_pos
+  ;;
 end
 
 let find t a b =
@@ -528,12 +543,6 @@ let find t a b =
   | Iterator.No_more -> failwith "Parsexp.Position.find"
 ;;
 
-let rec sub_sexp_count (sexp : Sexp.t) =
-  match sexp with
-  | Atom _ -> 1
-  | List l -> List.fold_left l ~init:1 ~f:(fun acc x -> acc + sub_sexp_count x)
-;;
-
 module Sexp_search = struct
   exception Found of int
 
