@@ -32,7 +32,7 @@ type pos =
   { line : int (** Line number. The first line has number [1].               *)
   ; col : int (** Column number. The first column has number [0].           *)
   ; offset : int
-  (** Number of bytes from the beginning of the input. The first
+      (** Number of bytes from the beginning of the input. The first
       byte has offset [0]. *)
   }
 [@@deriving_inline sexp_of]
@@ -146,5 +146,9 @@ module Iterator : sig
       next position and return it.
       Raises [No_more] when reaching the end of the position set. *)
   val advance_exn : t -> skip:int -> pos
+
+  (** Advance over a whole s-expression worth of positions. Returns the position range
+      corresponding to that s-expression. *)
+  val advance_sexp_exn : t -> Sexp.t -> range
 end
 with type positions := t
