@@ -1,12 +1,11 @@
-[@@@alert "-deprecated"]
-
-
 open! Import
 
 let test s =
   Single.parse_string s |> [%sexp_of: (Sexp.t, Parse_error.t) Result.t] |> print_s
 ;;
 
+let chars_of_string str = Queue.of_array (String.to_array str)
+
 let%expect_test "unterminated sexp" =
   test "(abc";
   [%expect
@@ -17,7 +16,7 @@ let%expect_test "unterminated sexp" =
         (col    4)
         (offset 4)))
       (message "unclosed parentheses at end of input")))
-  |}];
+    |}];
   test "  ";
   [%expect
     {|
@@ -27,7 +26,7 @@ let%expect_test "unterminated sexp" =
         (col    2)
         (offset 2)))
       (message "no s-expression found in input")))
-  |}]
+    |}]
 ;;
 
 let%expect_test "parsexp bug: it accepts invalid syntax" =
@@ -39,7 +38,8 @@ let%expect_test "parsexp bug: it accepts invalid syntax" =
         (line   1)
         (col    3)
         (offset 3)))
-      (message "unterminated sexp comment"))) |}];
+      (message "unterminated sexp comment")))
+    |}];
   test "#;(#;) a";
   [%expect
     {|
@@ -48,7 +48,8 @@ let%expect_test "parsexp bug: it accepts invalid syntax" =
         (line   1)
         (col    5)
         (offset 5)))
-      (message "unterminated sexp comment"))) |}];
+      (message "unterminated sexp comment")))
+    |}];
   test "#;";
   [%expect
     {|
@@ -57,7 +58,8 @@ let%expect_test "parsexp bug: it accepts invalid syntax" =
         (line   1)
         (col    2)
         (offset 2)))
-      (message "unterminated sexp comment"))) |}];
+      (message "unterminated sexp comment")))
+    |}];
   test "#;(#;q) (a)";
   [%expect {| (Ok (a)) |}];
   test "#;(#;(q)) (a)";
@@ -72,8 +74,7 @@ let%expect_test "parsexp bug: it accepts invalid syntax" =
 
 let%expect_test "regression test (used to raise s-expression followed by data)" =
   test "a #;0";
-  [%expect {|
-    (Ok a) |}]
+  [%expect {| (Ok a) |}]
 ;;
 
 let parse_eager_cst ~no_sexp_is_error str =
@@ -110,7 +111,8 @@ let%expect_test "regression test (we didn't run the callback on comments, result
             (line   1)
             (col    1)
             (offset 1)))))
-        (comment ";"))))) |}];
+        (comment ";")))))
+    |}];
   test "#||#";
   [%expect
     {|
@@ -126,7 +128,8 @@ let%expect_test "regression test (we didn't run the callback on comments, result
             (line   1)
             (col    4)
             (offset 4)))))
-        (comment "#||#"))))) |}];
+        (comment "#||#")))))
+    |}];
   test "#;#;a b";
   [%expect
     {|
@@ -169,7 +172,8 @@ let%expect_test "regression test (we didn't run the callback on comments, result
               (col    7)
               (offset 7)))))
           (atom b)
-          (unescaped (b)))))))) |}];
+          (unescaped (b))))))))
+    |}];
   test "a;\nb";
   [%expect
     {|
@@ -211,7 +215,8 @@ let%expect_test "regression test (we didn't run the callback on comments, result
             (col    1)
             (offset 4)))))
         (atom b)
-        (unescaped (b)))))) |}]
+        (unescaped (b))))))
+    |}]
 ;;
 
 let%expect_test "regression test (we counted comments as sexps for the purpose of \
@@ -231,7 +236,8 @@ let%expect_test "regression test (we counted comments as sexps for the purpose o
           (line   1)
           (col    1)
           (offset 1)))
-        (message "no s-expression found in input")))) |}];
+        (message "no s-expression found in input"))))
+    |}];
   test "#||#";
   [%expect
     {|
@@ -241,7 +247,8 @@ let%expect_test "regression test (we counted comments as sexps for the purpose o
           (line   1)
           (col    4)
           (offset 4)))
-        (message "no s-expression found in input")))) |}];
+        (message "no s-expression found in input"))))
+    |}];
   test "#;#;a b";
   [%expect
     {|
@@ -251,37 +258,38 @@ let%expect_test "regression test (we counted comments as sexps for the purpose o
           (line   1)
           (col    7)
           (offset 7)))
-        (message "no s-expression found in input")))) |}]
+        (message "no s-expression found in input"))))
+    |}]
 ;;
 
-module Stream = Stdlib.Stream
 module P = Eager
 
 let rec hot_loop state stream stack =
-  match Stream.peek stream with
+  match Queue.peek stream with
   | None -> P.feed_eoi state stack
   | Some char ->
     let stack = P.feed state char stack in
-    Stream.junk stream;
+    Queue.dequeue_and_ignore_exn stream;
     hot_loop state stream stack
 ;;
 
 exception Got_sexp of Sexp.t
 
-let fetch_sexp (stream : char Stream.t) =
+let fetch_sexp (stream : char Queue.t) =
   let got_sexp _state sexp = Exn.raise_without_backtrace (Got_sexp sexp) in
-  let count = Stream.count stream in
-  let state = P.State.create got_sexp in
+  let count = Queue.length stream in
+  let state = P.State.create ~reraise_notrace:true got_sexp in
   match hot_loop state stream P.Stack.empty with
   | () -> None
   | exception Got_sexp sexp ->
     (* This test is true if the s-expression includes the last character passed to
        the parser *)
-    if P.State.offset state > Stream.count stream - count then Stream.junk stream;
+    if P.State.offset state > count - Queue.length stream
+    then Queue.dequeue_and_ignore_exn stream;
     Some sexp
 ;;
 
-let iter_sexps (stream : char Stream.t) ~f =
+let iter_sexps (stream : char Queue.t) ~f =
   let got_sexp _state sexp = f sexp in
   let state = P.State.create got_sexp in
   hot_loop state stream P.Stack.empty
@@ -291,14 +299,15 @@ let input = {|
 (Hello World)
 (a b c)
 "Hello world"
+a(b)c"d"
 (1 (2 3))
 |}
 
 let%expect_test "eager parser raise" =
-  let stream = Stream.of_string input in
+  let stream = chars_of_string input in
   let rec loop stream =
     match fetch_sexp stream with
-    | None -> assert (Option.is_none (Stream.peek stream))
+    | None -> assert (Queue.is_empty stream)
     | Some sexp ->
       Stdlib.Format.printf "got: %a@." Sexp.pp_hum sexp;
       loop stream
@@ -309,7 +318,12 @@ let%expect_test "eager parser raise" =
     got: (Hello World)
     got: (a b c)
     got: "Hello world"
-    got: (1 (2 3)) |}]
+    got: a
+    got: (b)
+    got: c
+    got: d
+    got: (1 (2 3))
+    |}]
 ;;
 
 let all_short_strings () =
@@ -428,36 +442,51 @@ let%expect_test "eager parser semantics" =
 ;;
 
 let%expect_test "eager parser continue" =
-  let stream = Stream.of_string input in
+  let stream = chars_of_string input in
   iter_sexps stream ~f:(Stdlib.Format.printf "got: %a@." Sexp.pp_hum);
   [%expect
     {|
     got: (Hello World)
     got: (a b c)
     got: "Hello world"
+    got: a
+    got: (b)
+    got: c
+    got: d
     got: (1 (2 3))
-  |}]
+    |}]
 ;;
 
 let%expect_test "eager parser incorrect mutation" =
-  let stream = Stream.of_string input in
+  let stream = chars_of_string input in
   let state = ref (P.State.create (fun _ _ -> assert false)) in
   let got_sexp _state _sexp = P.State.reset !state in
   state := P.State.create got_sexp;
   show_raise ~hide_positions:true (fun () -> hot_loop !state stream P.Stack.empty);
-  [%expect {|
-    (raised "Assert_failure automaton_action.ml:LINE:COL")
-  |}]
+  [%expect {| (raised "Assert_failure automaton_action.ml:LINE:COL") |}]
 ;;
 
 let%expect_test "eager parser feed after raise without reset" =
-  let stream = Stream.of_string input in
+  let stream = chars_of_string input in
   let got_sexp _state _sexp = raise Stdlib.Exit in
   let state = P.State.create got_sexp in
   (try hot_loop state stream P.Stack.empty with
    | Stdlib.Exit -> ());
   show_raise (fun () -> hot_loop state stream P.Stack.empty);
-  [%expect {|
-    (raised (Failure "Parsexp.Parser_automaton: parser is dead"))
-  |}]
+  [%expect {| (raised (Failure "Parsexp.Parser_automaton: parser is dead")) |}]
+;;
+
+let%expect_test ("test for memory leak of most recently parsed sexp" [@tags "no-js"]) =
+  (* read a sexp option *)
+  let stream = chars_of_string input in
+  let open Core in
+  let option1 = fetch_sexp stream in
+  print_s [%sexp (option1 : Sexp.t option)];
+  [%expect {| ((Hello World)) |}];
+  let weak = Weak.create 1 in
+  Weak.set weak 0 option1;
+  (* sexp option no longer live after a major collection *)
+  Gc.full_major ();
+  print_s [%sexp (Weak.check weak 0 : bool)];
+  [%expect {| false |}]
 ;;
